Python: module TileStache.Goodies.AreaServer

TileStache.Goodies.AreaServer | index

`AreaServer supplies a tiny image server for use with TileStache providers
that implement renderArea() (http://tilestache.org/doc/#custom-providers).
The built-in Mapnik provider (http://tilestache.org/doc/#mapnik-provider)
is one example.
There are no tiles here, just a quick & dirty way of getting variously-sized
images out of a codebase that's ordinarily oriented toward tile generation.
Example usage, with gunicorn (http://gunicorn.org):
gunicorn --bind localhost:8888 "TileStache.Goodies.AreaServer:WSGIServer('tilestache.cfg')"
AreaServer URLs are compatible with the built-in URL Template provider
(http://tilestache.org/doc/#url-template-provider) and implement a generic
kind of WMS (http://en.wikipedia.org/wiki/Web_Map_Service).
All six URL parameters shown in this example are required; any other
URL parameter is ignored:
http://localhost:8888/layer-name?width=600&height=600&xmin=-100&ymin=-100&xmax=100&ymax=100`

Classes
`` |  | TileStache.WSGITileServer WSGIServer
class WSGIServer(TileStache.WSGITileServer)
`` | `WSGI Application that can handle WMS-style requests for static images. Inherits the constructor from TileStache WSGI, which just loads a TileStache configuration file into self.config. WSGITileServer autoreload argument is ignored, though. For now.`
| Methods defined here: __call__(self, environ, start_response) `Handle a request, using PATH_INFO and QUERY_STRING from environ. There are six required query string parameters: width, height, xmin, ymin, xmax and ymax. Layer name must be supplied in PATH_INFO.` Methods inherited from TileStache.WSGITileServer: __init__(self, config, autoreload=False) `Initialize a callable WSGI instance. Config parameter can be a file path string for a JSON configuration file or a configuration object with 'cache', 'layers', and 'dirpath' properties. Optional autoreload boolean parameter causes config to be re-read on each request, applicable only when config is a JSON file.`